@@ -43,15 +43,22 @@
 #'   execute_multiverse()
 #' }
 #'
-#' @importFrom dplyr mutate
-#' @importFrom future.apply future_lapply
+#' @importFrom furrr future_map
 #' @importFrom berryFunctions tryStack
 #' @importFrom utils txtProgressBar
 #' @importFrom utils setTxtProgressBar
 #' 
 #' @name execute
 #' @export
-execute_multiverse <- function(multiverse, parallel = FALSE, progress = FALSE) {
+execute_multiverse = function(multiverse, parallel = FALSE, progress = FALSE) {
+  if (getOption("tree", 1)) {
+    execute_tree(multiverse, parallel, progress)
+  } else {
+    execute_linear(multiverse, parallel, progress)
+  }
+}
+
+execute_tree <- function(multiverse, parallel, progress) {
   m_obj <- attr(multiverse, "multiverse")
   m_diction = attr(multiverse, "multiverse")$multiverse_diction
   
@@ -72,13 +79,60 @@ execute_multiverse <- function(multiverse, parallel = FALSE, progress = FALSE) {
   # we execute each step in sequence from top to bottom
   .res <- mapply(exec_all, .m_list, cumulative_l, MoreArgs = list(progressbar = pb, steps = steps, in_parallel = parallel))
   
-  
   # update multiverse diction with new elements
   m_diction$update(ordered_dict(.res))
-  
+
   m_obj$exec_all_until <- length(m_diction$as_list())
 }
 
+
+# execute linear
+# As an alternative to the tree-based hierarchical structure, we provide a simple linear execution framework
+# which avoids redundant computation but makes it significantly easier to perform execution in parallel
+execute_linear <- function(multiverse, parallel, progress) {
+  m_diction = attr(multiverse, "multiverse")$multiverse_diction
+  m_tbl = expand(multiverse)
+  .code_list = m_tbl[['.code']]
+  .env_list = m_tbl[['.results']]
+  
+  if (parallel) {
+    if (!requireNamespace("furrr", quietly = TRUE)) {
+      warning("Package furrr is required to perform parallel execution.")
+      app = lapply
+    } else {
+      app = future_map
+    }
+  } else {
+    app = lapply
+  }
+  
+  .res <- app(seq_along(.code_list), execute_linear_universe, .code_list, .env_list)
+  
+  handle_results_and_envs(.res, .env_list)
+  .error_messages = handle_errors(.res)
+  
+  .m_list = tail(attr(multiverse, "multiverse")$multiverse_diction$as_list(), 1)[[1]]
+ 
+  # save the errors to `list_block_exprs` (current level of m_list)
+  # return the updated `list_block_exprs`
+  .diction_res = list(
+    mapply(function(x, y) {x$error = y; return(list(x))}, .m_list, .error_messages)
+  )
+  names(.diction_res) = length(m_diction$as_list())
+  
+  m_diction$update(ordered_dict(.diction_res))
+  attr(multiverse, "multiverse")$exec_all_until <- length(m_diction$as_list())
+}
+
+# returns a named list of length 2 comprising of
+# a environment and a error_stack object
+execute_linear_universe <- function(i, code, env_list) {
+  .c = code[[i]]
+  .e = env_list[[i]]
+  .error_stack = tryStack( invisible(lapply(.c, eval, envir = .e)), silent = TRUE)
+  list(env = .e, ts = .error_stack)
+}
+
 # executes all the options resulting from decisions declared within a single code 
 # block in parallel. We do not need to communicate with other universes at this step
 # making it suitable for parallelisation.
@@ -90,11 +144,11 @@ exec_all <- function(list_block_exprs, current, progressbar, steps, in_parallel)
   # contain the result of the evaluated expression
   # as well as the error stack
   if (in_parallel) {
-    if (!requireNamespace("future.apply", quietly = TRUE)) {
+    if (!requireNamespace("furrr", quietly = TRUE)) {
       warning("")
       app = lapply
     } else {
-      app = future_lapply
+      app = future_map
     }
   } else {
     app = lapply
@@ -102,20 +156,8 @@ exec_all <- function(list_block_exprs, current, progressbar, steps, in_parallel)
   
   .res <- app(seq_along(.code_list), execute_each, .code_list, .env_list, progressbar, current, steps)
   
-  .error_messages = lapply(.res, function(x) x$ts)
-  .res_envs = lapply(.res, function(x) x$env)
-  
-  # updates the old environments in the dictionary with the new environments
-  mapply(function(old_env, new_env) {list2env(as.list(new_env), envir = old_env)}, .env_list, .res_envs)
-  
-  lapply(seq_along(.res), function(i, x) {
-    if (is(x[[i]], "try-error"))  {
-      warning("error in universe ", i)
-      cat(x[[i]], "\n\n")
-    }
-  }, x = .error_messages)
-  
-  .error_messages = lapply(.error_messages, function(x) { ifelse(is(x, "try-error"), x, NA) })
+  handle_results_and_envs(.res, .env_list)
+  .error_messages = handle_errors(.res)
   
   # save the errors to `list_block_exprs` (current level of m_list)
   # return the updated `list_block_exprs`
@@ -124,10 +166,37 @@ exec_all <- function(list_block_exprs, current, progressbar, steps, in_parallel)
   )
 }
 
+# input: .res, .env_list
+# output: NULL
+handle_results_and_envs = function(.res, .env_list) {
+  # creates a list of result environments
+  .res_envs = lapply(.res, function(x) x$env)
+  
+  # updates the old environments in the dictionary with the new environments
+  mapply(function(old_env, new_env) {list2env(as.list(new_env), envir = old_env)}, .env_list, .res_envs)
+}
+
+handle_errors = function(.res, .indices = NULL) {
+  # creates a list of error messages
+  .error_messages = lapply(.res, function(x) x$ts)
+  
+  if (is.null(.indices)) .indices = seq_along(.res)
+  
+  # prints the error messages
+  lapply(seq_along(.res), function(i, x) {
+    if (is(x[[i]], "try-error"))  {
+      warning("error in universe ", i)
+      cat("\n", x[[i]], "\n\n")
+    }
+  }, x = .error_messages)
+  
+  # returns the error messages (for multiverse table)
+  lapply(.error_messages, function(x) { ifelse(is(x, "try-error"), x, NA) })
+}
+
 execute_each <- function(i, code, env_list, pb, curr, n) {
   .c = code[[i]]
   .e = env_list[[i]]
-  # .env = new.env()
   .error_stack = tryStack(lapply(.c, eval, envir = .e), silent = TRUE)
   
   if (!is.null(pb)) {
@@ -137,46 +206,51 @@ execute_each <- function(i, code, env_list, pb, curr, n) {
   list(env = .e, ts = .error_stack)
 }
 
-
 #' @rdname execute
 #' @export
-execute_universe <- function(multiverse, .universe = 1) {
+execute_universe = function(multiverse, .universe = 1, parallel = FALSE, progress = FALSE) {
   m_diction = attr(multiverse, "multiverse")$multiverse_diction
-  # .level = attr(multiverse, "multiverse")$unchanged_until
-  # .level = attr(multiverse, "multiverse")$exec_all_until
-  # if (is.na(.level)) .level = 0
-  # we probably don't want to use cached execution when executing a single universe
-  
-  .order = get_exec_order(m_diction, .universe, length(m_diction$keys()))
-  .to_exec = seq_len(m_diction$size()) #tail(seq_len(m_diction$size()), n = m_diction$size() - .level)
-  
-  .m_list <- m_diction$as_list()[.to_exec]
-  
-  .res <- mapply(exec_in_order, .m_list, .to_exec, MoreArgs = list(.universes = .order))
-}
 
-execute_code_from_universe <- function(.c, .env = globalenv()) {
-  tryStack(lapply(.c, eval, envir = .env), silent = TRUE)
-}
-
-# for a universe, get the indices which need to be executed
-get_exec_order <- function(.m_diction, .uni, .level) {
-  if (.level > 1){
-    .p <- .m_diction$get(.m_diction$keys()[[.level]])[[.uni]]$parent
-    c(get_exec_order(.m_diction, .p, .level - 1), .uni)
+  m_tbl = expand(multiverse)
+  .code_list = m_tbl[[".code"]]
+  .env_list = m_tbl[[".results"]]
+  
+  if ((length(.universe) > 1) & parallel) {
+    .res = future_map(.universe, execute_linear_universe, .code_list, .env_list, .progress = progress)
   } else {
-    .uni
+    .res = lapply(.universe, execute_linear_universe, .code_list, .env_list)
   }
-}
-
-exec_in_order <- function(.universe_list, .universes, .i) {
-  x <- .universe_list[[ .universes[[.i]] ]]
   
-  .exec_res <- execute_code_from_universe(x$code, x$env)
-  if (is(.exec_res, "try-error"))  warning("error in default universe", "\n", .exec_res)
-  else if (is(.exec_res, "warning"))  warning("warning in default universe", "\n", .exec_res)
+  .res_envs = lapply(.res, function(x) x$env)
+  # .errors = lapply(.res, function(x) x$ts)
+  .errors = lapply(seq_along(.env_list), 
+                   function(x, y, i) { 
+                     if(x %in% i) y[[1]]$ts else NULL  
+                   }, .res, .universe)
+
+  mapply(function(old_env, new_env) {list2env(as.list(new_env), envir = old_env)}, .env_list[.universe], .res_envs)
+  
+  # prints the error messages
+  lapply(seq_along(.errors), function(i, x) {
+    if (is(x[[i]], "try-error"))  {
+      warning("error in universe ", i)
+      cat("\n", x[[i]], "\n\n")
+    }
+  }, x = .errors)
+  
+  # returns the error messages (for multiverse table)
+  .error_messages = lapply(.errors, function(x) { ifelse(is(x, "try-error"), x, NA) })
+
+  .m_list = tail(attr(multiverse, "multiverse")$multiverse_diction$as_list(), 1)
+
+  # # save the errors to `list_block_exprs` (current level of m_list)
+  # # return the updated `list_block_exprs`
+  .diction_res = list(
+    mapply(function(x, y) {x$error = y; return(list(x))}, .m_list[[1]], .error_messages)
+  )
+  names(.diction_res) = names(.m_list)
+
+  m_diction$update(ordered_dict(.diction_res))
+  attr(multiverse, "multiverse")$exec_all_until <- 0
 }
 
-
-
-
